##
## Add the proven and probable reserves for the current producers to the total 
## produced gold. Model, using linear regression, the total produced gold plus 
## these selected reserves as a function of the production order. Plot the 
## results (Figure 10). 
##

library(readxl)
library(dplyr)

CalcProductionOrder <- function(productionYear, seed = NULL){
  
  set.seed(seed)
  su_year <- sort(unique(productionYear))
  productionOrder <- vector(mode = "integer", length = length(productionYear))
  
  resample <- function(x, ...) x[sample.int(length(x), ...)]
  endIndex <- 0
  for(i in seq_along(su_year)){
    areCurrentYear <- su_year[i] == productionYear
    startIndex <- endIndex + 1
    endIndex <- endIndex + sum(areCurrentYear)
    indices <- startIndex:endIndex
    productionOrder[areCurrentYear] <- resample(indices)
  }
  
  return(productionOrder)  
}

rawData <- read_xlsx("Data\\ProductionAndReserveData.xlsx", 
                     sheet = "Resource Data", skip = 3,
                     col_names = FALSE)

# Elminate those rows for which the starting year (rawData[[11]]) is missing
# and the status (rawData[[3]]) is a developed prospect with reserves
rawData <- rawData[!is.na(rawData[[11]]) & rawData[[3]] != "DEVELOPED PROSPECT WITH RESERVES", ]



rawData$Classification <- ifelse(rawData[[3]] == "PRODUCING MINE", "Current Producer", "Past Producer")

# current producer with reserve data
areInCategory1 <- rawData$Classification == "Current Producer" &
  (!is.na(rawData[[21]]) | !is.na(rawData[[25]]))
cat(sprintf("Number of current producers with reserve data = %d\n",
            sum(areInCategory1)))

# current producer without reserve data
areInCategory2 <- rawData$Classification == "Current Producer" &
  !(!is.na(rawData[[21]]) | !is.na(rawData[[25]]))
cat(sprintf("Number of current producers without reserve data = %d\n",
            sum(areInCategory2)))

# past producer with reserve data
areInCategory3 <- rawData$Classification == "Past Producer" &
  (!is.na(rawData[[21]]) | !is.na(rawData[[25]]))
cat(sprintf("Number of past producers with reserve data = %d\n",
            sum(areInCategory3)))

# past producer without reserve data
areInCategory4 <- rawData$Classification == "Past Producer" &
  !(!is.na(rawData[[21]]) | !is.na(rawData[[25]]))
cat(sprintf("Number of past producers with reserve data = %d\n",
            sum(areInCategory4)))

# The units for ore are metric tons, the units for gold are grams, and
# the units for grade are grams per metric ton.
mineData <- tibble(Name = rawData[[1]],
                   Longitude = rawData[[5]],
                   Latitude = rawData[[4]],
                   Status = rawData[[3]],
                   Classification = ifelse(Status == "PRODUCING MINE", "Current Producer", "Past Producer"),
                   StartingYear = rawData[[11]],
                   OreTons_tp = rawData[[12]],
                   GoldGrams_tp = rawData[[13]],
                   OreTons = rawData[[12]],
                   GoldGrams = rawData[[13]],
                   Grade = vector(mode = "numeric", length = nrow(rawData))
)

# Add probable and proven reserves to only the current producers
for(i in 1:nrow(mineData)){
  if(mineData[i, "Classification"] == "Current Producer"){
    # Probable reserves
    if(!is.na(rawData[[21]][i])){
      mineData[i, "OreTons"] <- mineData[i, "OreTons"] + rawData[[21]][i]
      mineData[i, "GoldGrams"] <- mineData[i, "GoldGrams"] + rawData[[21]][i] * rawData[[22]][i]
    }
    # Proven reserves
    if(!is.na(rawData[[25]][i])){
      mineData[i, "OreTons"] <- mineData[i, "OreTons"] + rawData[[25]][i]
      mineData[i, "GoldGrams"] <- mineData[i, "GoldGrams"] + rawData[[25]][i] * rawData[[26]][i]
    }
    
  }
}

mineData$Grade <- mineData$GoldGrams / mineData$OreTons
mineData$productionOrder <- CalcProductionOrder(mineData$StartingYear, seed = 7)

####-------------------------------------------------------------------------

fit <- lm(log10(GoldGrams) ~ productionOrder, data = mineData)
summary(fit)

tmp <- summary(fit)$coefficients
intercept <- tmp[1,1]
slope <- tmp[2,1]
std_err <- tmp[2,2]

df1 <- data_frame(x = sort(mineData$productionOrder),
                  y = intercept + slope * x)

# DeGroot and Schervish, p. 625, eqn 10.3.20
n <- nrow(mineData)
S2 <- sum(fit$residuals^2)
sigma_prime <- sqrt(S2 / (n - 2))
sx <- sqrt(sum((mineData$productionOrder - mean(mineData$productionOrder))^2))
df2 <- data_frame(x = seq(from = slope - 3 * std_err, to = slope + 3 * std_err, length.out = 1000),
                  z = (x - slope) / (sigma_prime / sx),
                  y = sx / sigma_prime * dt(z, n-2))

####-------------------------------------------------------------------------
# Figure 10

p1 <- ggplot(mineData) +
  geom_line(aes(x = x, y = y), data = df1, color = "blue", size = 1) +
  geom_point(aes(x = productionOrder, y = log10(GoldGrams)), 
             data = mineData, shape = 16, color = "black") +
  geom_point(aes(x = productionOrder, y = log10(GoldGrams_tp)), 
             data = mineData, shape = 1, color = "black") +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = quote(log[10]("Total produced gold plus selected reserves")))  +
  theme_bw() +
  ggtitle("A.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
  theme(legend.position = "none")

p2 <- ggplot(df2) +
  geom_line(aes(x = x, y = y)) +
  geom_vline(xintercept = 0.0, color = "gray75") +
  geom_rug(aes(x = slope), data = data_frame(slope = slope), color = "blue", size = 2) +
  scale_x_continuous(name = "Slope") +
  scale_y_continuous(name = "Density")  +
  theme_bw() +
  ggtitle("B.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(1,3)))
plot(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1:2))
plot(p2, vp=grid::viewport(layout.pos.row=1, layout.pos.col=3))


