##
## Generate maps showing the locations of the Abitibi region and the 
## Timmins-Kirkland lake area (Figure 1).
##

library(ggplot2)
library(ggmap)
library(tibble)

library(sp)
library(rgdal)

# ----------------

if(file.exists("Data\\area_map.rds")){
  area_map <- readRDS("Data\\area_map.rds")
} else{
  area_map <- get_googlemap(center = c(-80.75, 48.25), 
                            size=c(450,450), 
                            zoom = 5,
                            maptype="hybrid")
  saveRDS(area_map, "Data\\area_map.rds")  
}

AbitibiRegion <- readOGR("AbitibiRegion", "AbitibiRegion")
tmp <- coordinates(AbitibiRegion@polygons[[1]]@Polygons[[1]])
df_abitibi <- tibble(long = tmp[, 1], lat = tmp[, 2])

df_roi <- tibble(lat = c(47.50,47.50,49.00,49.00), 
                     long = c(-79.50,-82.00,-82.00,-79.50))

df_labels <- tibble(lat = c(48.1, 47.3, 47.1, 50.8, 41.7),
                    long = c(-86.7, -86.7, -79.3, -77.0, -82.5),
                    label = c("Canada", "United States",
                              "Timmins-Kirkland\nLake area",
                              "Abitibi greenstone belt",
                              "Base map data from Google, 2018"))

p1 <- ggmap(area_map) + 
  geom_polygon(aes(x = long, y = lat), data = df_abitibi, 
               color = "orange", fill = "orange") +
  geom_polygon(aes(x = long, y = lat), data = df_roi, 
               fill = NA, color = "red", size = 1) +
  geom_text(aes(x = long, y = lat, label = label), 
            data = df_labels[1:2, ], 
            color = "white", angle = -30) +
  geom_text(aes(x = long, y = lat, label = label), 
            data = df_labels[3, ], 
            color = "red", size = 4, fontface = "bold", hjust = "left", angle = 0) +
  geom_text(aes(x = long, y = lat, label = label), 
            data = df_labels[4, ], 
            color = "orange", size = 4, fontface = "bold", hjust = "center", angle = 0) +
  geom_label(aes(x = long, y = lat, label = label), data = df_labels[5, ], 
             color = "black", size = 4, fontface = "bold", hjust = "left") +
  xlab("") +
  ylab("") +
  ggtitle("A.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10))
  
# ----------------

if(file.exists("Data\\study_area_map.rds")){
  study_area_map <- readRDS("Data\\study_area_map.rds")
} else{
  study_area_map <- get_googlemap(center = c(-80.75, 48.25),
                                  size=c(240,240),
                                  zoom = 7,
                                  maptype="satellite")
  saveRDS(study_area_map, "Data\\study_area_map.rds")  
}

load("Data\\mineData.dat")

faults <- readOGR("MainBreaks", "MainBreaks")

camps <- readOGR("MiningCamp", "MiningCamp")

df_labels <- tibble(lat = c(48.51, 48.30, 48.60, 47.92, 48.47611, 48.15029, 47.42),
                    long = c(-81.6, -79.95, -79.95, -80.15, -81.32891, -80.0354, -81.0),
                    label = c("Porcupine mining camp",
                              "Kirkland Lake\nmining camp",
                              "Porcupine-\nDestor break",
                              "Kirkland Lake-\nLarder Lake-\nLake Cadillac\nbreak",
                              "Timmins",
                              "Kirkland Lake",
                              "Base map data from Google, 2018"))

# Legend
df_legend_box <- tibble(long = c(-82., -82., -81.20, -81.20),
                      lat = c(47.4, 48.05, 48.05, 47.4))

df_rake <- tibble(long = c(-81.8, -81.9, -81.9, -81.8),
                  lat = c(47.5, 47.5, 47.5 + 0.225, 47.5 + 0.225))
df_rake_labels <- tibble(lat = c(47.5, 47.5 + 0.225, 47.5 + 0.113),
                         long = c(-81.75, -81.75, -81.7),
                         label = c("0", "25", "Distance,\nin kilometers "))
df_mine <- tibble(long = -81.85,
                  lat = 47.81)
df_mine_label <- tibble(long = -81.70,
                        lat = 47.81,
                        label = "Mine")
df_fault <- tibble(long = c(-81.9, -81.8),
                   lat = c(47.885, 47.885))
df_fault_label <- tibble(long = -81.70,
                        lat = 47.885,
                        label = "Fault")

tmp <- coordinates(camps@polygons[[1]]@Polygons[[1]])
df_camp <- tibble(long = 0.15 * (tmp[, 1] - mean(tmp[, 1])) - 81.85,
             lat = 0.15 * (tmp[, 2] - mean(tmp[, 2])) + 47.960)
df_camp_label <- tibble(long = -81.70,
                         lat = 47.960,
                         label = "Mining camp")



p2 <- ggmap(study_area_map)

for(i in 1:length(camps@polygons)){
  tmp <- coordinates(camps@polygons[[i]]@Polygons[[1]])
  df_tmp <- tibble(long = tmp[, 1], lat = tmp[, 2])
  p2 <- p2 + 
    geom_polygon(aes(x = long, y = lat), data = df_tmp, color = NA,
                 fill = "black", alpha = 1)
}
for(i in 1:length(faults@lines)){
  tmp <- coordinates(faults@lines[[i]])[[1]]
  df_tmp <- tibble(long = tmp[, 1], lat = tmp[, 2])
  p2 <- p2 +
    geom_line(aes(x = long, y = lat), data = df_tmp, size = 1, color = "red")
}
p2 <- p2 +
  geom_point(aes(x = Longitude, y = Latitude),
             data = mineData, 
             shape = 16, color = "green") +
  geom_text(aes(x = long, y = lat, label = label), data = df_labels[1, ], 
            color = "white", size = 3, fontface = "bold", hjust = "left", angle = 22) +
  geom_text(aes(x = long, y = lat, label = label), data = df_labels[2, ], 
            color = "white", size = 3, fontface = "bold", hjust = "left", angle = -10) +
  geom_text(aes(x = long, y = lat, label = label), data = df_labels[3, ], 
            color = "white", size = 3, fontface = "bold", hjust = "left", angle = 5) +
  geom_text(aes(x = long, y = lat, label = label), data = df_labels[4, ], 
            color = "white", size = 3, fontface = "bold", hjust = "right", angle = 27) +
  geom_label(aes(x = long, y = lat, label = label), data = df_labels[7, ], 
            color = "black", size = 4, fontface = "bold", hjust = "left") +
  # geom_point(aes(x = long, y = lat), data = df_labels[5, ], shape = 16, color = "red") +
  # geom_point(aes(x = long, y = lat), data = df_labels[6, ], shape = 16, color = "red") +
  geom_polygon(aes(x = long, y = lat), data = df_legend_box, 
               fill = "white", color = "black") +
  geom_path(aes(x = long, y = lat), data = df_rake, color = "black") +
  geom_text(aes(x = long, y = lat, label = label), data = df_rake_labels, 
            color = "black", size = 3, fontface = "bold", hjust = "left") +
  geom_point(aes(x = long, y = lat), data = df_mine, 
             shape = 16, color = "green") +
  geom_text(aes(x = long, y = lat, label = label), data = df_mine_label, 
            color = "black", size = 3, fontface = "bold", hjust = "left") +
  geom_line(aes(x = long, y = lat), data = df_fault, 
            size = 1, color = "red") +
  geom_text(aes(x = long, y = lat, label = label), data = df_fault_label, 
            color = "black", size = 3, fontface = "bold", hjust = "left") +
  geom_polygon(aes(x = long, y = lat), data = df_camp, color = NA,
               fill = "black", alpha = 1) +
  geom_text(aes(x = long, y = lat, label = label), data = df_camp_label, 
            color = "black", size = 3, fontface = "bold", hjust = "left") +
  
  xlab("") +
  ylab("") +
  ggtitle("B.") +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) 

tiff(filename = "figure_1.tif", width = 890, height = 480, units = "px")
grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(1,2)))
print(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
print(p2, vp=grid::viewport(layout.pos.row=1, layout.pos.col=2))
dev.off()


