##
## Plot the total produced gold as a function of production order (Figure 5),
## showing how mines are partioned between an existing mine or a future mine.
## Plot the distribution of the total produced gold in the existing mines (Figure 6A)
## and plot the distribution of the total produced gold in the futre mines 
## (Figure 6B). Calculate the ratio between the means for the existing and 
## future mines. Likewise, calculate the ratio between the medians. Plot the 
## ratios (Figure 7A and 7B).
##

library(ggplot2)
library(dplyr)
library(MapMark4)

load("Data\\mineData.dat")

# ---------------
# Determine the year between production orders 29 and 30
theOrder <- order(mineData$productionOrder)
tmp <- cbind(mineData$StartingYear, mineData$productionOrder)
print(tmp[theOrder, ])

# ---------------
# Figure 5

df_text1 <- data.frame(x = 8.5, y = 1.5e5, text = "Existing mines")
df_text2 <- data.frame(x = 12.5, y = 1.5e5, text = "Future mines")


p <- ggplot(mineData) +
  geom_vline(xintercept = 10.5, linetype = "dashed") +
  geom_text(aes(x = x, y = y, label = text),
            data = df_text1, hjust = "right", size = 10.0 / (72.27 / 25.4)) +
  geom_text(aes(x = x, y = y, label = text),
            data = df_text2, hjust = "left", size = 10.0 / (72.27 / 25.4)) +
  geom_point(aes(x = productionOrder, y = GoldGrams),
             data = mineData, shape = 16, color = "black") +
  scale_x_continuous(name = "Production order",
                     breaks = seq(from = 0, to = 80, by = 10)) +
  scale_y_continuous(name = "Total produced gold,\nin grams", trans = "log10",
                     breaks = 10^(5:8))  +
  theme_bw() +
  theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
  theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

# postscript(file = "figure_5.ps", width = 6.5, height = 2.5)
print(p)
# dev.off()

# ---------------
# Figure 6

PlotDotPlot <- function(theData, figLabel, xLimits = NULL, xBreaks = waiver()){
  
  p <- ggplot(data_frame(theData = theData)) +
    geom_dotplot(aes(x = theData), 
                 method = "histodot", dotsize = 1/2) +
    scale_x_continuous(name = "Total produced gold, in grams",
                       trans = "log10", limits = xLimits, breaks = xBreaks) +
    scale_y_continuous(name = "\n\n", breaks = NULL) +
    theme_bw() +
    ggtitle(figLabel) +
    theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
  return(p)
}


areExistingMines <- mineData$productionOrder <= 10

xLimits <- c(3e4, 1e9)
xBreaks <- 10^c(5:9)
p1 <- PlotDotPlot(mineData$GoldGrams[areExistingMines], "A. Existing Mines", 
                  xLimits = xLimits, xBreaks = xBreaks)

p2 <- PlotDotPlot(mineData$GoldGrams[!areExistingMines], "B. Future Mines", 
                  xLimits = xLimits, xBreaks = xBreaks)

# postscript(file = "figure_6.ps", width = 6.5, height = 3.75)
grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(2,1)))
print(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
print(p2, vp=grid::viewport(layout.pos.row=2, layout.pos.col=1))
# dev.off()

cat(sprintf("Ratio of means = %g\n",
            mean(mineData$GoldGrams[areExistingMines]) / mean(mineData$GoldGrams[!areExistingMines])))

# ---------------
# Figure 7

CalcRatio <- function(nExistingMines, mineData, FUNC){
  
  areExistingMines <- mineData$productionOrder <= nExistingMines
  
  ratio <- FUNC(mineData$GoldGrams[areExistingMines]) / FUNC(mineData$GoldGrams[!areExistingMines])
  
  return(ratio)
}


# number of mines at the time of assessment
nExistingMines <- seq(from = 10L, to = 52L, by = 1L)
N <- length(nExistingMines)

ratios <- data_frame(
  nExistingMines = factor(nExistingMines),
  theMean = vector(mode = "numeric", length = N),
  theMedian = vector(mode = "numeric", length = N)
)

for(i in 1:N){
  ratios[i, ] <- c(nExistingMines[i], 
                   CalcRatio(nExistingMines[i], mineData, mean),
                   CalcRatio(nExistingMines[i], mineData, median))
}

theRange <- range(ratios$theMean)
cat(sprintf("Range of the ratios of means: %g   %g\n",
            theRange[1], theRange[2]))

theRange <- range(ratios$theMedian)
cat(sprintf("Range of the ratios of medians: %g   %g\n",
            theRange[1], theRange[2]))

PlotRatios <- function(df, stat, figTitle, yAxisTitle, yLimits = NULL, 
                       yBreaks = waiver()){
  
  p <- ggplot(df) +
    geom_hline(yintercept = 1.0, color = "green") +
    geom_point(aes_(x = quote(nExistingMines), y = as.name(stat))) +
    scale_y_continuous(name = yAxisTitle, 
                       limits = yLimits,
                       breaks = yBreaks) +
    scale_x_discrete(name = "Number of existing mines") +
    ggtitle(figTitle) +
    theme_bw() +
    theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())

  return(p)
}

yLimits = c(0,8)
p1 <- PlotRatios(ratios, "theMean", "A.", "Ratio of means", yLimits = yLimits)
p2 <- PlotRatios(ratios, "theMedian", "B.", "Ratio of medians", yLimits = yLimits)

# postscript(file = "figure_7.ps", width = 6.5, height = 4.0)
grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(2,1)))
print(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
print(p2, vp=grid::viewport(layout.pos.row=2, layout.pos.col=1))
# dev.off()

