##
## Plot the pdf that represents the predicted total produced gold for 52 future 
## mines (Figure 8). Calculate the ratio between the pdf mean and the sample 
## mean for the future mines. Likewise, the ratio between the pdf median and 
## the sample mean for the future mines.  Plot the ratios (Figure 9A and 9B). 
## 

library(ggplot2)
library(dplyr)
library(tidyr)
library(MapMark4)

load("Data\\mineData.dat")

# ---------------
# Figure 8

PlotPdf <- function(rs, theData, xLimits = NULL, xBreaks = waiver()) {

  n <- length(rs)
  if(n > 5000) {
    indices <- sample.int(n, size = 5000)
    df <- data_frame(rs = rs[indices])
  } else {
    df <- data_frame(rs = rs)
  }

  p <- ggplot(df) +
    geom_density(aes(x = rs), adjust = 2) +
    geom_rug(aes(x = x), data = data_frame(x = theData), color = "black") +
    scale_x_continuous(name = "Total produced gold, in grams", trans = "log10",
                       limits = xLimits, breaks = xBreaks) +
    scale_y_continuous(name = "Density") +
    theme_bw() +
    theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank())
  return(p)
}


areExistingMines <- mineData$productionOrder <= 10

model <- data.frame(ID = factor(""),
                    Name = factor(""),
                    Gold = mineData$GoldGrams[areExistingMines] / 1.0e6)

pdf <- TonnagePdf(model, pdfType = "normal", minNDeposits = 10,
                  isTruncated = FALSE, nRandomSamples = 5.0e4, seed = 777)

xLimits <- c(1e4, 3e11)
xBreaks <- 10^c(4:11)
p1 <- PlotPdf(pdf$rs * 1.0e6, mineData$GoldGrams[!areExistingMines],
              xLimits = xLimits, xBreaks = xBreaks)

print(p1)

# ---------------

CalcRatios <- function(nExistingMines, mineData, FUNC){
  
  areExistingMines <- mineData$productionOrder <= nExistingMines

  model <- data.frame(ID = factor(""),
                      Name = factor(""),
                      Gold = mineData$GoldGrams[areExistingMines] / 1.0e6)
  
  pdf1 <- TonnagePdf(model, pdfType = "normal", minNDeposits = 10, 
                    isTruncated = FALSE, nRandomSamples = 5.0e4, seed = 777)
  
  pdf2 <- TonnagePdf(model, pdfType = "normal", minNDeposits = 10, 
                     isTruncated = TRUE, nRandomSamples = 5.0e4, seed = 777)

  pdf3 <- TonnagePdf(model, pdfType = "kde", minNDeposits = 10, 
                     isTruncated = FALSE, nRandomSamples = 5.0e4, seed = 777)

  pdf4 <- TonnagePdf(model, pdfType = "kde", minNDeposits = 10, 
                     isTruncated = TRUE, nRandomSamples = 5.0e4, seed = 777)
  
  theCenter <- FUNC(mineData$GoldGrams[!areExistingMines])
  ratios <- c(
    pdf1 = FUNC(pdf1$rs * 1.0e6) / theCenter,
    pdf2 = FUNC(pdf2$rs * 1.0e6) / theCenter,
    pdf3 = FUNC(pdf3$rs * 1.0e6) / theCenter,
    pdf4 = FUNC(pdf4$rs * 1.0e6) / theCenter
  )
  
  return(ratios)
}

# ---------------
# Calculate the ratios

# number of mines at the time of assessment
nExistingMines <- seq(from = 10L, to = 52L, by = 1L)
N <- length(nExistingMines)

ratio_means <- data_frame(
  nExistingMines = factor(nExistingMines),
  pdf1 = vector(mode = "numeric", length = N),
  pdf2 = vector(mode = "numeric", length = N),
  pdf3 = vector(mode = "numeric", length = N),
  pdf4 = vector(mode = "numeric", length = N)
)

ratio_medians <- ratio_means
  
for(i in 1:N){

  print(nExistingMines[i])
  
  ratio_means[i, ] <- c(nExistingMines[i], CalcRatios(nExistingMines[i], mineData, mean))
  ratio_medians[i, ] <- c(nExistingMines[i], CalcRatios(nExistingMines[i], mineData, median))
  
}

save(ratio_means, ratio_medians, file = "Data\\Ratios.dat")


# ---------------
# Figure 9

PlotRatios <- function(df, figTitle, yAxisTitle, yLimits = NULL, yBreaks = waiver(),
                       legend_position = "none"){
  
  p <- ggplot(gather(df, key = pdf, value = ratio, 'pdf1':'pdf4')) +
    geom_hline(yintercept = 1.0, color = "green") +
    geom_point(aes(x = nExistingMines, y = ratio, color = pdf)) +
    scale_y_continuous(name = yAxisTitle, 
                       limits = yLimits,
                       breaks = yBreaks) +
    scale_x_discrete(name = "Number of existing mines") +
    scale_color_brewer(name = "Probability Density Function",
                       labels = c("Log-normal", "Truncated log-normal", 
                                  "Kernel density estimate", "Truncated kernel density estimate"),
                       type = "seq", palette = "Spectral") +
    ggtitle(figTitle) +
    theme_bw() +
    theme(plot.title=element_text(hjust = 0,face = "bold.italic", size = 10)) +
    theme(panel.grid.major = element_blank(), panel.grid.minor = element_blank()) +
    theme(legend.position = legend_position, legend.background = element_rect(color = "black"))
  
  return(p)
}

# postscript(file = "figure_9a.ps", width = 6.5, height = 3.5)
yLimits <- c(0, 12.5)
p1 <- PlotRatios(ratio_means, "A.", "Ratio of means", 
                 yLimits = yLimits, legend_position = "none")
p2 <- PlotRatios(ratio_medians, "B.", "Ratio of medians", 
                 yLimits = yLimits, legend_position = "none")

grid::grid.newpage()
grid::pushViewport(grid::viewport(layout=grid::grid.layout(2,1)))
print(p1, vp=grid::viewport(layout.pos.row=1, layout.pos.col=1))
print(p2, vp=grid::viewport(layout.pos.row=2, layout.pos.col=1))
# dev.off()

cat(sprintf("Range of ratios for the means %g   %g\n",
            min(ratio_means[, -1]), max(ratio_means[, -1])))
cat(sprintf("Range of ratios for the means %g   %g\n",
            min(ratio_medians[, -1]), max(ratio_medians[, -1])))
